# jamd-viewer
Just Another Markdown viewer.
A multiplatform desktop markdown viewer powered by [flask-desktop-ui](https://github.com/jamofer/flask-desktop-ui)

## Install
```shell
pip install jamd-viewer
```

## Usage
```shell
jamd readme.md
```
